@@ -19,7 +19,7 @@ class GUIRunner(AbstractRunner, threading.Thread):
     Args:
         urls: 2GIS URLs with items to be collected.
         output_path: Path to the result file.
-        format: `csv` or `json` format.
+        format: `csv`, `xlsx` or `json` format.
         config: Configuration.
     """
     def __init__(self, urls: list[str], output_path: str, format: str,
