@@ -1,11 +1,12 @@
 from .options import WriterOptions, CSVOptions
-from .writers import CSVWriter, JSONWriter, FileWriter
+from .writers import CSVWriter, JSONWriter, FileWriter, XLSXWriter
 from .factory import get_writer
 
 __all__ = [
     'WriterOptions',
     'CSVOptions',
     'CSVWriter',
+    'XLSXWriter',
     'JSONWriter',
     'FileWriter',
     'get_writer',
