@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-from .writers import CSVWriter, FileWriter, JSONWriter
+from .writers import CSVWriter, XLSXWriter, FileWriter, JSONWriter
 
 from .exceptions import WriterUnknownFileFormat
 
@@ -15,7 +15,7 @@ def get_writer(file_path: str, file_format: str, writer_options: WriterOptions)
 
     Args:
         output_path: Path to thr result file.
-        format: `csv` or `json` format.
+        format: `csv`, `xlsx` or `json` format.
         writer_options: Writer options.
 
     Returns:
@@ -26,5 +26,7 @@ def get_writer(file_path: str, file_format: str, writer_options: WriterOptions)
         return JSONWriter(file_path, writer_options)
     elif file_format == 'csv':
         return CSVWriter(file_path, writer_options)
+    elif file_format == 'xlsx':
+        return XLSXWriter(file_path, writer_options)
 
     raise WriterUnknownFileFormat('Неизвестный формат файла: %s', file_format)
